import unittest
import sasktran as sk
import numpy as np


class TestEngineHR(unittest.TestCase):
    def test_format_xarray(self):
        tanalts_km = np.arange(10, 50, 1)

        # First recreate our geometry and atmosphere classes
        geometry = sk.VerticalImage()
        geometry.from_sza_saa(sza=60, saa=60, lat=0, lon=0, tanalts_km=tanalts_km, mjd=54372, locallook=0,
                              satalt_km=600, refalt_km=20)

        atmosphere = sk.Atmosphere()

        atmosphere['ozone'] = sk.Species(sk.O3OSIRISRes(), sk.Labow())
        atmosphere['air'] = sk.Species(sk.Rayleigh(), sk.MSIS90())

        atmosphere.wf_species = 'ozone'

        # And now make the engine
        engine = sk.EngineHR(geometry=geometry, atmosphere=atmosphere)
        engine.num_orders_of_scatter = 1

        # Choose some wavelengths to do the calculation at
        engine.wavelengths = [340, 600]

        # And do the calculation
        radiance = engine.calculate_radiance('xarray')

    def test_format_xarray_scalar(self):
        tanalts_km = np.arange(10, 50, 1)

        # First recreate our geometry and atmosphere classes
        geometry = sk.VerticalImage()
        geometry.from_sza_saa(sza=60, saa=60, lat=0, lon=0, tanalts_km=tanalts_km, mjd=54372, locallook=0,
                              satalt_km=600, refalt_km=20)

        atmosphere = sk.Atmosphere()

        atmosphere['ozone'] = sk.Species(sk.O3OSIRISRes(), sk.Labow())
        atmosphere['air'] = sk.Species(sk.Rayleigh(), sk.MSIS90())

        atmosphere.wf_species = 'ozone'

        # And now make the engine
        engine = sk.EngineHR(geometry=geometry, atmosphere=atmosphere)
        engine.num_orders_of_scatter = 1

        # Choose some wavelengths to do the calculation at
        engine.wavelengths = 340

        # And do the calculation
        radiance = engine.calculate_radiance('xarray')

    def test_polarized(self):
        tanalts_km = np.arange(10, 50, 1)

        # First recreate our geometry and atmosphere classes
        geometry = sk.VerticalImage()
        geometry.from_sza_saa(sza=60, saa=60, lat=0, lon=0, tanalts_km=tanalts_km, mjd=54372, locallook=0,
                              satalt_km=600, refalt_km=20)

        atmosphere = sk.Atmosphere()

        atmosphere['ozone'] = sk.Species(sk.O3OSIRISRes(), sk.Labow())
        atmosphere['air'] = sk.Species(sk.Rayleigh(), sk.MSIS90())

        atmosphere.wf_species = 'ozone'

        # And now make the engine
        engine = sk.EngineHR(geometry=geometry, atmosphere=atmosphere)
        engine.num_orders_of_scatter = 1

        # Choose some wavelengths to do the calculation at
        engine.wavelengths = [340, 600]

        # And do the calculation
        radiance = engine.calculate_radiance('xarray', full_stokes_vector=True)